==> alg-example-1.9.12-20190319.031933-3-sources.jar: cn/com/duiba/nezha/alg/example/constant/ProjectConstant.java <==
package cn.com.duiba.nezha.alg.example.constant;

public class ProjectConstant {
    public static final String CONFIG_PATH = "/application.properties";
    public static String KAFKA_BROKERS = "nezha.compute.kafka.brokers";
    public static String ZK_LIST = "nezha.compute.zk.list";

    public static String HIVE_URL = "nezha.compute.hive.url";

    public static String MD_W_HOST ="nezha.compute.mongo.web.host";
    public static String MD_W_KEY="nezha.compute.mongo.web.key";


    public static String REDIS_IP = "nezha.compute.redis.ip";
    public static String REDIS_PW = "nezha.compute.redis.password";
    public static String REDIS_PORT = "nezha.compute.redis.port";



    // Hbase Constant

    public static String TABLE_NAME = "";

    public static int REDIS_PORT_DEAFULT = 6379;
    public static int MAX_IDLE = 20;
    public static int MIN_IDLE = 5;
    public static int MAX_TOTAL = 20;

    //等待可用连接的最大时间，单位毫秒，默认值为-1，表示永不超时。如果超过等待时间，则直接抛出JedisConnectionException；
    public static int MAX_WAIT_MILLIS = 5000;

    public static int RETRY_NUM = 3;
    public static int TIME_OUT = 5000;

    public static Boolean TEST_ON_BORROW = false;
    public static Boolean TEST_ON_RETURN = false;


    // redis expire
    public static int YEAR_1_EXPIRE = (60*60*24)*365;
    public static int MONTH_3_EXPIRE = (60*60*24)*30*3;
    public static int MONTH_1_EXPIRE = (60*60*24)*30;
    public static int WEEK_1_EXPIRE = (60*60*24)*7;
    public static int WEEK_2_EXPIRE = (60*60*24)*7*2;
    public static int DAY_2_EXPIRE = (60*60*24)*2;
    public static int DAY_1_EXPIRE = (60*60*24)*1;
    public static int HOUR_1_EXPIRE = (60*60)*1;
    public static int MINUTE_1_EXPIRE = 60*1;
    public static int MINUTE_20_EXPIRE = 60*20;


}

==> alg-example-2.23.84-sources.jar: cn/com/duiba/nezha/alg/example/constant/ProjectConstant.java <==
package cn.com.duiba.nezha.alg.example.constant;

public class ProjectConstant {
    public static final String CONFIG_PATH = "/application.properties";
    public static String KAFKA_BROKERS = "nezha.compute.kafka.brokers";
    public static String ZK_LIST = "nezha.compute.zk.list";

    public static String HIVE_URL = "nezha.compute.hive.url";

    public static String MD_W_HOST ="nezha.compute.mongo.web.host";
    public static String MD_W_KEY="nezha.compute.mongo.web.key";


    public static String REDIS_IP = "nezha.compute.redis.ip";
    public static String REDIS_PW = "nezha.compute.redis.password";
    public static String REDIS_PORT = "nezha.compute.redis.port";


    public static String REDIS_ACT_IP = "act.engine.redis.ip";
    public static String REDIS_ACT_PW = "act.engine.redis.password";
    public static String REDIS_ACT_PORT = "act.engine.redis.port";

    public static String REDIS_DPA_ACT_IP = "dpa.act.engine.redis.ip";
    public static String REDIS_DPA_ACT_PW = "dpa.act.engine.redis.password";
    public static String REDIS_DPA_ACT_PORT = "dpa.act.engine.redis.port";



    // Hbase Constant

    public static String TABLE_NAME = "";

    public static int REDIS_PORT_DEAFULT = 6379;
    public static int MAX_IDLE = 20;
    public static int MIN_IDLE = 5;
    public static int MAX_TOTAL = 20;

    //等待可用连接的最大时间，单位毫秒，默认值为-1，表示永不超时。如果超过等待时间，则直接抛出JedisConnectionException；
    public static int MAX_WAIT_MILLIS = 5000;

    public static int RETRY_NUM = 3;
    public static int TIME_OUT = 5000;

    public static Boolean TEST_ON_BORROW = false;
    public static Boolean TEST_ON_RETURN = false;


    // redis expire
    public static int YEAR_1_EXPIRE = (60*60*24)*365;
    public static int MONTH_3_EXPIRE = (60*60*24)*30*3;
    public static int MONTH_1_EXPIRE = (60*60*24)*30;
    public static int WEEK_1_EXPIRE = (60*60*24)*7;
    public static int WEEK_2_EXPIRE = (60*60*24)*7*2;
    public static int DAY_2_EXPIRE = (60*60*24)*2;
    public static int DAY_1_EXPIRE = (60*60*24)*1;
    public static int HOUR_1_EXPIRE = (60*60)*1;
    public static int MINUTE_1_EXPIRE = 60*1;
    public static int MINUTE_20_EXPIRE = 60*20;


}
